@@ -49,8 +49,8 @@ class Experiment_Setup:
         out.writei('#!/bin/bash\n')
         if self.pbs_expt:
 	    if self.queue != None: out.writei('#PBS -q {0}\n'.format(self.queue))
-            #out.writei('#PBS -l nodes=1:ppn={0},walltime={1}\n'.format(max(self.dim_async,self.y_async),self.walltime))
-            out.writei('#PBS -l nodes=1:ppn={0}\n'.format(max(self.dim_async,self.y_async)))
+            #out.writei('#PBS -l nodes=1:ppn={0},walltime={1}\n'.format(max(self.dim_async,self.m_async),self.walltime))
+            out.writei('#PBS -l nodes=1:ppn={0}\n'.format(max(self.dim_async,self.m_async)))
             out.writei('#PBS -N {0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.run_id,self.experiment))
             out.writei('#PBS -o {5}/pbs_out/{0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.run_id,self.experiment,self.source_dir))
             out.writei('#PBS -e {5}/pbs_err/{0}_{1}_{2}_{3}_{4}\n'.format(self.years[0],self.years[1],self.model,self.run_id,self.experiment,self.source_dir))
@@ -79,15 +79,19 @@ class Experiment_Setup:
         out.writei('CDB_ROOT_TEMP_DIR="{0}"\n'.format(self.temp_dir))
         out.writei('if [ -z "${PBS_JOBID}" ]; then\n')
         out.inc_indent()
-        out.writei('CDB_TEMP_DIR="${CDB_ROOT_TEMP_DIR}/${CDB_DIAG_NAME}.jod_pid${$}"\n')
+        out.writei('export CDB_TEMP_DIR="${CDB_ROOT_TEMP_DIR}/${CDB_DIAG_NAME}.jod_pid${$}"\n')
         out.dec_indent()
         out.writei('else\n')
         out.inc_indent()
-        out.writei('CDB_TEMP_DIR="${CDB_ROOT_TEMP_DIR}/${CDB_DIAG_NAME}.pbs_job_${PBS_JOBID}"\n')
+        out.writei('export CDB_TEMP_DIR="${CDB_ROOT_TEMP_DIR}/${CDB_DIAG_NAME}.pbs_job_${PBS_JOBID}"\n')
         out.dec_indent()
         out.writei('fi\n')
         out.writei('mkdir -p ${CDB_TEMP_DIR}\n')
         out.writei('\n')
+        out.writei('#Subset the data pointers file and put it in temporary directory for optimal retrieval:\n')
+        out.writei('CDB_DIAG_HEADER_BASE=$(basename ${CDB_DIAG_HEADER%.gz})\n')
+        out.writei('cdb_query_archive slice --experiment=${CDB_EXPT} --model=${CDB_MODEL} --center=${CDB_CENTER} --rip=${CDB_RUN_ID} ${CDB_DIAG_HEADER} ${CDB_TEMP_DIR}/${CDB_DIAG_HEADER_BASE}\n')
+        out.writei('CDB_DIAG_HEADER="${CDB_TEMP_DIR}/${CDB_DIAG_HEADER_BASE}"\n')
 
         
         #LOAD SCRIPT FILE AND CONVERT PARALLEL INSTANCES
@@ -260,6 +264,7 @@ def start_monthly_loop(self,out):
     out.writei('CDB_EXPT=${CDB_EXPT}\n')
     out.writei('CDB_DIAG_NAME=${CDB_DIAG_NAME}\n')
     out.writei('CDB_DIAG_HEADER=${CDB_DIAG_HEADER}\n')
+    out.writei('CDB_TEMP_DIR=${CDB_TEMP_DIR}\n')
     out.writei('CDB_OUT_FILE=${CDB_OUT_FILE}_${CDB_YEAR}_${CDB_MONTH}\n')
     #for type_var in cdb_environment_variables.keys():
     #    for name_var in cdb_environment_variables[type_var]:
@@ -270,6 +275,8 @@ def start_monthly_loop(self,out):
     out.open.write('EndOfScriptHeader\n')
     out.writei('\n')
     out.writei('cat >> $3 <<\'EndOfScriptMain\'\n')
+    out.writei('\n')
+    out.writei('#Retrieve path names to data:\n')
     for var_name in self.variable_list.keys():
         retrieval_string='${CDB_CENTER} ${CDB_MODEL} ${CDB_EXPT} ${CDB_RUN_ID} '
         retrieval_string+=var_name+' '
@@ -278,6 +285,19 @@ def start_monthly_loop(self,out):
         retrieval_string+=' ${CDB_DIAG_HEADER}'
         out.writei('CDB_'+var_name+'_'+'_'.join(self.variable_list[var_name])+'=$(cdb_query_archive retrieve '+retrieval_string+')\n')
         out.writei('CDB_'+var_name+'_'+'_'.join(self.variable_list[var_name])+'_TYPE=$(cdb_query_archive retrieve -f '+retrieval_string+')\n')
+    out.writei('\n')
+    out.writei('#Create a cdo retrieval script:\n')
+    out.writei('CDO_RETRIEVAL_SCRIPT="cdo merge "\n')
+    for var_name in self.variable_list.keys():
+        var_id = '$CDB_'+var_name+'_'+'_'.join(self.variable_list[var_name])
+        out.writei('#Creating retrieval for {0}\n'.format(var_name))
+        out.writei('CDB_VAR=$(echo '+var_id+'| awk -F\'|\' \'{print $1}\')\n')
+        out.writei('CDB_VAR_START=$(echo '+var_id+' | awk -F\'|\' \'{print $2}\')\n')
+        out.writei('CDB_VAR_END=$(echo '+var_id+' | awk -F\'|\' \'{print $3}\')\n')
+        out.writei('CDB_TIME_STEPS=$(echo $(seq $((CDB_VAR_START+1)) $((CDB_VAR_END+1))) | tr \' \' \',\')\n')
+        out.writei('CDO_RETRIEVAL_SCRIPT="${CDO_RETRIEVAL_SCRIPT} -selname,'+var_name+' -seltimestep,${CDB_TIME_STEPS} $CDB_VAR"\n')
+        
+
 
         #if self.time_diff:
         #    retrieval_string='${CDB_CENTER} ${CDB_MODEL} ${CDB_EXPT} ${CDB_RUN_ID} '
@@ -335,10 +355,10 @@ def end_monthly_loop(self,out):
     #Process the monthly_scripts
     if self.debug:
         out.writei('for SCRIPT in $(ls ${CDB_TEMP_DIR}/script_????_??.sh); do bash $SCRIPT; rm $SCRIPT; done\n')
-    elif self.y_async == 1:
+    elif self.m_async == 1:
         out.writei('for SCRIPT in $(ls ${CDB_TEMP_DIR}/script_????_??.sh); do bash $SCRIPT > ${CDB_OUT_DIR}/${CDB_OUT_FILE}.out 2>&1; rm $SCRIPT; done\n')
     else:
-        out.writei('ls ${CDB_TEMP_DIR}/script_????_??.sh | parallel --tmpdir ${CDB_OUT_DIR} -k -j'+str(self.y_async)+' "bash {}" > ${CDB_OUT_DIR}/${CDB_OUT_FILE}.out 2>&1 &\n')
+        out.writei('ls ${CDB_TEMP_DIR}/script_????_??.sh | parallel --tmpdir ${CDB_OUT_DIR} -k -j'+str(self.m_async)+' "bash {}" > ${CDB_OUT_DIR}/${CDB_OUT_FILE}.out 2>&1 &\n')
         out.writei('pid=${!}\n')
         out.writei('${CDB_SOURCE_DIR}/parallel_ramdisk.sh $pid ${CDB_TEMP_DIR}\n')
         out.writei('rm ${CDB_TEMP_DIR}/script_????_??.sh\n')
@@ -368,7 +388,10 @@ def main():
     setup_group=parser.add_argument_group("Setup","These options must be set when using this script")
     setup_group.add_argument("--debug",dest="debug",
                       default=False, action="store_true",
-                      help="Debug flag. Disables options --y_async and --dim_async.")
+                      help="Debug flag. Disables options --m_async and --dim_async.")
+    setup_group.add_argument("--run",dest="run",
+                      default=False, action="store_true",
+                      help="Launches the scripts.")
     #setup_group.add_argument("--time_diff",dest="time_diff",
     #                  default=False, action="store_true",
     #                  help="Request the month before and the month after: allows to take a time derivative.\n\
@@ -386,31 +409,32 @@ def main():
                       help="pbs job walltime. Inactive for now: Determined by queue")
     proc_group.add_argument("-q","--queue",dest="queue",
                       default=None,
-                      help="PBS queue")
-    proc_group.add_argument("-S","--submit",dest="submit",
+                      help="PBS queue type")
+    proc_group.add_argument("--submit",dest="submit",
                       default=False, action="store_true",
-                      help="PBS queue")
-    proc_group.add_argument("--y_async",dest="y_async",
+                      help="Submit scripts to the PBS queue")
+    proc_group.add_argument("--m_async",dest="m_async",
                       default=1,
-                      help="Uses the specified # of processors for the asynchronous processing of years.\n\
+                      help="Uses the specified # of processors for the asynchronous processing of months.\n\
                             Cannot be used with --dim_async. Requires NCO version 4.0.0 and above, gnu-parallel.")
     proc_group.add_argument("--dim_async",dest="dim_async",
                       default=1,
                       help="Uses the specified # of processors in dimension splitting.\n\
-                            Cannot be used with --y_async. Requires NCO version 4.0.0 and above, gnu-parallel.")
+                            Cannot be used with --m_async. Requires NCO version 4.0.0 and above, gnu-parallel.")
 
     options = parser.parse_args()
 
     #Disable asynchronous computing if debugging
     if options.debug:
-        options.y_async=1
+        options.m_async=1
         options.dim_async=1
 
-    if options.y_async>1 and options.dim_async>1:
-        raise IOError('Can only specify Y_ASYNC>1 or --DIM_ASYNC>1, but not both.')
+    if options.m_async>1 and options.dim_async>1:
+        raise IOError('Can only specify M_ASYNC>1 or --DIM_ASYNC>1, but not both.')
 
     #Load diagnostic description file:
     if options.diag_header[-3:]=='.gz':
+        import gzip
         infile=gzip.open(options.diag_header,'r')
     else:
         infile=open(options.diag_header,'r')
@@ -452,7 +476,10 @@ def main():
                 experiment = Experiment_Setup(options)
                 experiment.prepare_scripts()
 
-                #if options.submit:
+                #if options.run:
+                #
+                #elif options.submit:
+
 
 if __name__ == "__main__":
     main()
