@@ -1,42 +1,16 @@
 import os
-import json
 import copy
-import sqlalchemy
-import sqlalchemy.orm
 from pyesgf.search import SearchConnection
-from netCDF4 import Dataset
 
-class File_Expt(object):
-    #Create a class that can be used with sqlachemy:
-    def __init__(self,diag_tree_desc):
-        for tree_desc in diag_tree_desc:
-            setattr(self,tree_desc,'')
-        self.path=''
+import database_utils
+from database_utils import File_Expt
 
-def load_database(diag_tree_desc):
-    #This function creates an in-memory sqlite database, for easy subselecting.
-
-    engine = sqlalchemy.create_engine('sqlite:///:memory:', echo=False)
-    metadata = sqlalchemy.MetaData(bind=engine)
-
-    time_db = sqlalchemy.Table('time_db',metadata,
-            sqlalchemy.Column('case_id',sqlalchemy.Integer,primary_key=True),
-            sqlalchemy.Column('path',sqlalchemy.String(255)),
-            *(sqlalchemy.Column(diag_tree, sqlalchemy.String(255)) for diag_tree in diag_tree_desc)
-            )
-    metadata.create_all()
-    sqlalchemy.orm.clear_mappers()
-    sqlalchemy.orm.mapper(File_Expt,time_db)
-
-    session = sqlalchemy.orm.create_session(bind=engine, autocommit=False, autoflush=True)
-    return session, time_db
-
-def create_dict(search_path,file_type_list,variable_list,experiment_list,diag_tree_desc):
+def descend_tree(search_path,file_type_list,variable_list,experiment_list,diag_tree_desc):
     #This function generates the database
     diag_tree_desc.append('file_type')
     diag_tree_desc.append('path')
 
-    session, time_db = load_database(diag_tree_desc)
+    session, time_db = database_utils.load_database(diag_tree_desc)
     file_expt = File_Expt(diag_tree_desc)
 
     #Create the database:
@@ -46,7 +20,7 @@ def create_dict(search_path,file_type_list,variable_list,experiment_list,diag_tr
 
     paths_dict={}
     for item in session.query(File_Expt).all():
-        paths_dict=create_tree(item,diag_tree_desc,paths_dict)
+        paths_dict=database_utils.create_tree(item,diag_tree_desc,paths_dict)
 
     return paths_dict
 
@@ -92,7 +66,7 @@ def experiment_variable_search(session,file_expt,search_path,file_type_list,expe
                             keys_dict['mip']=file_description[5]
                             keys_dict['version']=file_description[7]
                             #Create database entry:
-                            create_entry(session,file_expt_copy,keys_dict)
+                            database_utils.create_entry(session,file_expt_copy,keys_dict)
 
         if 'OPeNDAP' in file_type_list:
             #OPeNDAP files were requested:
@@ -114,40 +88,7 @@ def experiment_variable_search(session,file_expt,search_path,file_type_list,expe
                         keys_dict['mip']=file_description[-4]
                         keys_dict['version']='v'+file_description[-1].replace('v','')
                         #Create database entry:
-                        create_entry(session,file_expt_copy,keys_dict)
+                        database_utils.create_entry(session,file_expt_copy,keys_dict)
 
     return
 
-def create_entry(session,file_expt,keys_dict):
-    for key in keys_dict.keys():
-        setattr(file_expt,key,keys_dict[key])
-    session.add(file_expt)
-    session.commit()
-
-def create_tree(item,diag_tree_desc,paths_dict):
-    #This function recursively creates the output dictionary from one database entry:
-    if len(diag_tree_desc)>2 and isinstance(diag_tree_desc,list):
-        if '_name' not in paths_dict.keys():
-            paths_dict['_name']=diag_tree_desc[0]
-        dict_name=getattr(item,diag_tree_desc[0])
-
-        if dict_name not in paths_dict.keys():
-            paths_dict[dict_name]={}
-        paths_dict[dict_name]==create_tree(item,diag_tree_desc[1:],paths_dict[dict_name])
-
-    elif len(diag_tree_desc)==2 and isinstance(diag_tree_desc,list):
-        if '_name' not in paths_dict.keys():
-            paths_dict['_name']=diag_tree_desc[0]
-        dict_name=getattr(item,diag_tree_desc[0])
-
-        if dict_name not in paths_dict.keys():
-            paths_dict[dict_name]=[]
-        paths_dict[dict_name].append(create_tree(item,diag_tree_desc[1:],paths_dict[dict_name]))
-    else:
-        if isinstance(diag_tree_desc,list):
-            diag_tree_desc=diag_tree_desc[0]
-
-        paths_dict=getattr(item,diag_tree_desc)
-    return paths_dict
-        
-    
